@@ -1,3 +1,4 @@
 use Email::Address;
 $value = q{first@foo.org,} . q{ } x 26 . q{second@foo.org};
-Email::Address->parse($value);
+use Data::Dumper;
+print Dumper(Email::Address->parse($value));
